@@ -137,10 +137,19 @@ class SSHClient(object):
                 return_code = channel.recv_exit_status()
                 return ExecResult(return_code, output, stderr)
             else:
-                stdin, stdout, stderr = self.__ssh.exec_command(cmd,timeout=timeout)
-                exit_status = stdout.channel.recv_exit_status()
-                std_output = stdout.read().decode()
-                std_err = stderr.read().decode()
+                # stdin, stdout, stderr = self.__ssh.exec_command(cmd,timeout=timeout)
+                # exit_status = stdout.channel.recv_exit_status()
+                # std_output = stdout.read().decode()
+                # std_err = stderr.read().decode()
+                shell=self.__ssh.invoke_shell()
+                shell.send(f"{cmd}\n")
+                stdout=""
+                stderr=""
+                while shell.recv_ready():
+                    stdout+=shell.recv(1024).decode('utf-8', 'ignore')
+                while shell.recv_stderr_ready():
+                    stderr+=shell.recv_stderr(2024).decode('utf-8', 'ignore')
+                exit_status=shell.recv_exit_status()
                 log.info(
                     f" {self.__ip}:{self.__port} | successful to run cmd {cmd}, output is:{std_output}.")
                 return ExecResult(exit_status, std_output, std_err)
